\name{F1}
\alias{F1}
\encoding{latin1}
\title{SIMPLE SCATTER PLOT FOR VARIABLE X QUANTITATIVE}
\description{It performs a simple scatter plot with or without text labels and a regression model.}
\usage{
F1(data, varY, varX, textlabel=NULL, label=NULL, reg=FALSE, model="Linear",
outliers=FALSE, quant1=0.05, quant2=0.95, ci=TRUE, level=0.95, ResetPAR=TRUE,
PAR=NULL, XLAB=NULL, YLAB=NULL, COLOR="black", COLORR="red", PCH=16, lty=1,
ltyci=2, lwd=2.5, R2.pos="topleft", PLOT=NULL, LEGEND=NULL, AXIS=NULL,
MTEXT=NULL, TEXT=NULL, dec=",", file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Quantitative independent variable.}
  \item{textlabel}{Variable with the text labels.}
  \item{label}{It allows to specify the characteristics of the text labels with the function \link[graphics]{text}.}
  \item{reg}{If TRUE a regression model is performed.}
  \item{model}{One regression model can be selected: "Linear" , "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic", "Inverse".  It is not considered the model in those cases in which there is the logarithm that apply to any of the variables, if any value of the variable, which applies the logarithm, is zero or negative. The inverse model is not calculated if any value of the independent variable is zero.}
\item{outliers}{If it is TRUE, the outliers are removed using the selected regression model.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{ci}{If it is TRUE the confidence interval is depicted, but only for the linear regression model.}
  \item{level}{Tolerance/confidence level.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{COLOR}{Color of the symbols.}
  \item{COLORR}{Color of the line of the regression model.}
  \item{PCH}{Graphic symbol (see the figure below).
  \tabular{r}{
  \figure{E1}{options: width=2.3in}
  }
  }
  \item{lty}{Type of the regression line (see the figure below).
  \tabular{r}{
  \figure{E2}{options: width=0.4in}
  }
  }
  \item{ltyci}{Type of the confidence interval line (see above figure).}
  \item{lwd}{Line width of the regression line.}
  \item{R2.pos}{If it is not NULL, with this argument is possible to specify the position of the \eqn{r^2} of the regression in the scatter plot.}
  \item{PLOT}{It allows to specify the characteristics of the function \link[graphics]{plot.default}.}
  \item{LEGEND}{It allows to include a legend to the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{file}{TXT FILE. If the argument \emph{reg=TRUE} a TXT file is saved with the information of the regression.}
}
\value{A simple scatter plot with or without linear regression is obtained. Moreover, a TXT file is saved with the results of the regression model.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[graphics]{plot.default} of base graphics package and the linear regression with the function \link[stats]{lm} of base stats package. The function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) is used to perform the test of Normality Kolmogorov-Smirnov with Lilliefors'correction, the function \link[lmtest]{dwtest} of the package lmtest (Hothorn et al., 2013) to analyze the autocorrelation with the test and the Durbin-Watson statistic function \link[lmtest]{bptest} of the package lmtest (Hothorn et al., 2013) to perform the Breusch-Pagan test of homoscedasticity.

\strong{EXAMPLES}

\strong{Example 1} The data are scores of a Principal Component Analysis (PCA) performed to physicochemical parameters from lakes in Colombia. In this example, text labels are assigned to the points with the argument \emph{textlabel="Lake"}.
\tabular{c}{
\figure{F25}{options: width=3.5in}
}
\strong{Example 2} For the examples, morphometric data of several fish species of Characiforms, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010). It is shown the relationship between M11 and M13 for all species.
\tabular{c}{
\figure{F20}{options: width=3.5in}
}
\strong{Example 3} A linear regression line is added to the example 2 with the argument \emph{reg=TRUE}.
\tabular{c}{
\figure{F21}{options: width=3.5in}
}
In the TXT file that generates the function, the regression model linear is shown, where the variable M11 is significant (p < 0.001, see \emph{Pr(>|t|)}) and, therefore, the model as a whole was also significant (p < 0.001, see \emph{p-value} at the end of the results).

The \eqn{r^2} (see \emph{Multiple R-squared}) shows that the M11 explains a 89.4\% of the observed variance in the M13. The \eqn{r^2} adjusted (see \emph{Ajusted R-squared}) takes into account the size of the sample to determine the proportion above and, in this case, it is the same. The \eqn{r^2} adjusted should be used to compare models with different numbers of observations or independent variables. The equation of the potential regression model must be expressed in this way:
\eqn{M13=-0.024+1.069*M11}
\tabular{c}{
\figure{R3}{options: width=3.7in}
}
In the following table, the results of the test of Kolmogorov-Smirnov normality with Lilliefors' correction are shown, the test for autocorrelation of Durbin-Watson statistic and the Breusch-Pagan test of homoscedasticity.

\strong{Normality} The residuals do not have a Normal distribution with p = 0.073. Although is not complied with the assumption of normality, this does not invalidate the model as it is very predictive with a \eqn{r^2} very high. The problem resulting from these residuals are not Normal is that there can be no assurance that the degree of significance, probability value that shows the model, is the correct one.

\strong{Autocorrelation} The requirement that there should be no autocorrelation is no longer met the test of Durbin-Watson statistic p < 0.001. This means that the value of \eqn{r^ 2} of the 89.4\% is not all due to the dependent variable, the M11, but it is also in part due to the own dependent variable that is auto explained and, therefore, it is not possible to know exactly how much is the variance explained by the independent variable. Anyway it is necessary to mention that the probability value of the test of Durbin-Watson statistic can be less than 0.05 easily when there are many data. The statistical DW, whose value is 0.39 in this example, is a better indicator of the autocorrelation when the number of data is very large. According to Durbin & Watson (1951), a DW less than 1 means a strong positive autocorrelation, a DW greater than 4 a strong negative autocorrelation, values between 1 and 3 a moderate autocorrelation, and a value close to 2 means that there is no autocorrelation. Therefore, it can be concluded that there is a strong positive autocorrelation in this example.

\strong{Homoscedasticity} Finally, the requirement of homoscedasticity of the residuals is not satisfied, because the likelihood of the Breusch-Pagan test is p < 0.001. The fact of not fulfilled this requirement means that the model is not as predictive for the entire range of values of the dependent variable.
\tabular{c}{
\figure{R4}{options: width=3.8in}
}
}
\references{
Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, \strong{38}, 159-171.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{https://CRAN.R-project.org/package=nortest}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Hothorn, T. et al., (2013) Testing Linear Regression Models. R package version 0.9-33. Available at: \url{https://CRAN.R-project.org/package=lmtest}.
}
\examples{
\dontrun{

#Example 1

data(Z6)

F1(data=Z6, varY="Dimension2", varX="Dimension1", textlabel="Lake",
XLAB="Dimension 1", YLAB="Dimension 2",PLOT = c("xlim= c(-1,1)",
"xlab=xlab", "ylab=ylab", "col=COLOR", "pch=PCH"))

#Example 2

data(Z1)

F1(data=Z1, varY="M13", varX="M11")

#Example 3

F1(data=Z1, varY="M13", varX="M11", reg=TRUE)
}
}
\keyword{F1}
