\name{F3}
\alias{F3}
\encoding{latin1}
\title{FUNCTION SURFACE PLOTS}
\description{Display a function surface plot.}
\usage{
F3(data, X, Y, func, theta=120, phi=15, ticktype="detailed", PERSP=NULL,
ResetPAR=TRUE, PAR=NULL, XLAB=NULL, YLAB=NULL, ZLAB=NULL, XLIM=NULL,
YLIM=NULL, ZLIM=NULL, COLOR="red", LEGEND=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{X}{Variable X.}
  \item{Y}{Variable Y.}
  \item{func}{Function of the response surface plot.}
  \item{theta}{Angle defining the azimuthal direction.}
  \item{phi}{Angle defining the colatitude direction.}
  \item{ticktype}{Character: "simple" draws just an arrow parallel to the axis to indicate direction of increase and "detailed" draws normal ticks as per 2D plots.}
  \item{PERSP}{It allows to specify the characteristics of the function \link[graphics]{persp}.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{ZLAB}{Legend of the Z axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{ZLIM}{Vector with the limits of the Z axis.}
  \item{COLOR}{Color of the surface.}
  \item{LEGEND}{It allows to include a legend to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A function surface plot is obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[graphics]{persp} of the base package graphics. For further details see the help of the function \link[graphics]{persp} and/or Guisande & Vammonde (2012).

\strong{EXAMPLES}

\strong{Example 1.} Function \eqn{x^{2}+y^{2}+1}.
\tabular{c}{
\figure{F57}{options: width=3.8in}
}
\strong{Example 2.} Function \eqn{x^{2}-y^{2}}.
\tabular{c}{
\figure{F58}{options: width=3.8in}
}
\strong{Example 3.} Function \eqn{x^{3}-y^{2}}.
\tabular{c}{
\figure{F59}{options: width=3.6in}
}
\strong{Example 4.} Function \eqn{x^{3}+y^{3}} and the azimuthal direction is modified with the argument \emph{theta=150}.
\tabular{c}{
\figure{F60}{options: width=3.6in}
}
}
\references{
Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.
}
\examples{
\dontrun{

data(Z9)

#Example 1

F3(data=Z9, X="x", Y="y", func="x^2 + y^2 + 1")

#Example 2

F3(data=Z9, X="x", Y="y", func="x^2 - y^2", COLOR="green")

#Example 3

F3(data=Z9, X="x", Y="y", func="x^3 - y^2", COLOR="orange")

#Example 4

F3(data=Z9, X="x", Y="y", func="x^3 + y^3",  theta=150, COLOR="grey80")
}
}
\keyword{F3}
