\name{F37}
\alias{F37}
\title{OPTIMAL ENVIRONMENTAL DIAGRAMS}
\description{
This function allows to show in a plot the environmental conditions were there are a higher number of records of one or several species, so it is possible to determine the niche conditions of one or several species and, to create boxplots with the range of environmental variables and list of species in an area of the niche selected by the user.
}
\usage{
F37(data, variables, Level="NULL", Taxon="NULL", cor=TRUE, ResetPAR=TRUE, PAR=NULL,
d.main=0.5, xlab="Polar coordinate X in pixels", ylab="Polar coordinate Y in pixels",
cex.labS=1.5, font.lab=1, main="", colramp = IDPcolorRamp, cex.main = 2,
font.main=2, nlab.xaxis = 5, nlab.yaxis = 5, minL.axis = 3, las = 1,
border = FALSE, tcl = -0.3, boxplot=TRUE, outline=FALSE, color="NULL",
range = 1.5, width = NULL, varwidth = FALSE, plot = TRUE, 
pars = list(boxwex = 0.8, staplewex = 0.5, outwex = 0.5), cex.boxplot=1.5,
cex.labB=1.5, namesB, family="serif", line=1, file1="List of species.csv",
file2="Environmental variables.csv", na="NA", dec=",", row.names=FALSE,
fileEncoding = "")
}
\arguments{
  \item{data}{A CSV file obtained from ModestR (Garca-Rosell et al., 2013) with data which show the presence of the species and abiotic and/or biotic factors.}
  \item{variables}{Selection of the variables for the estimation of the niche.}
  \item{Level}{Taxonomic level to be selected, i.e., class, order, family, genus or species.}
  \item{Taxon}{Name of the taxon or taxa selected within the level, i.e., name of the Order, Family, etc. Can be a vector, so several taxa.}
  \item{cor}{If TRUE the variables are ordered according to the correlation between them when estimating the polar coordinates. Therefore, the next variable to another variable is the one that has a greater positive correlation.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{d.main}{Scatter plot. Vertical distance between upper border of scatter plots and the title line in multiples of title height.}
  \item{xlab}{Scatter plot. Label for x-axis.}
  \item{ylab}{Scatter plot. Label for y-axis.}
  \item{cex.labS}{Scatter plot. Magnification used for text in axis labels
relative to the current setting of cex.}
  \item{font.lab}{Scatter plot. The font to be used for x and y labels.}
  \item{main}{Scatter plot. Title of the plot.}
  \item{colramp}{Scatter plot. Color ramp to encode the number of counts within a pixel.}
  \item{cex.main}{Scatter plot. Magnification used for title relative to the current setting of cex.}
  \item{font.main}{Scatter plot. The font to be used for plot main titles.}
  \item{nlab.xaxis}{Scatter plot. Approximate number of labels on x-axes.}
  \item{nlab.yaxis}{Scatter plot. Approximate number of labels on y-axes.}
  \item{minL.axis}{Scatter plot. The minimum length of the abbreviations of factor levels, used to label the axes ticks.}
  \item{las}{Scatter plot. Orientation of labels on axes.}
  \item{border}{Scatter plot. Logical. When TRUE, a border is drawn around the individual colors in the legend.}
  \item{tcl}{Scatter plot. The length of tick marks as a fraction of the height of a line of text. The default value is -0.5; setting tcl = NA sets tck = -0.01 which is S' default.}
  \item{boxplot}{If TRUE (the default) then a boxplot with the range of environmental variables in an area of the niche selected by the user is produced.}
  \item{outline}{Boxplot. If outline is not true, the outliers are not drawn (as points whereas S+ uses lines).}
  \item{color}{Boxplot. If col is non-null it is assumed to contain colors to be used to colour the bodies of the box plots.}
  \item{range}{Boxplot. This determines how far the plot whiskers extend out from the box. If the range is positive, the whiskers extend to the most extreme data point which is no more than range times the interquartile range from the box. A value of zero causes the whiskers to extend to the data extremes.}
  \item{width}{Boxplot. A vector giving the relative widths of the boxes making up the plot.}
  \item{varwidth}{Boxplot. If varwidth is TRUE, the boxes are drawn with widths proportional to the square-roots of the number of observations in the groups.}
  \item{plot}{Boxplot. If TRUE (the default) then a boxplot is produced. If not, the summaries which the boxplots are based on are returned.}
  \item{pars}{Boxplot. A list of (potentially many) more graphical
parameters, e.g., boxwex or outpch; these are passed to bxp (if plot is true).}
  \item{cex.boxplot}{Boxplot. Magnification used for axis annotation.}
  \item{cex.labB}{Boxplot. Magnification used for group labels which will be printed under each boxplot.}
  \item{namesB}{Boxplot. Group labels which will be printed under each boxplot. It can be a character vector.}
  \item{family}{The name of a font family for drawing text.}
  \item{line}{mtext. On which margin line, starting at 0 counting outwards.}
  \item{file1}{CSV file. A character string naming the file of the list of species.}
  \item{file2}{CSV file. A character string naming the file with the summary of the environmental variables.}
  \item{na}{CSV files. The string to use for missing values in the data.}
  \item{dec}{CSV files. The string to use for decimal points in numeric or complex columns: must be a single character.}
  \item{row.names}{CSV files. Either a logical value indicating whether the row names of x are to be written along with x, or a character vector of row names to be written.}
  \item{fileEncoding}{CSV files. Character string: if non-empty declares the encoding to be used on a file (not a connection) so the character data can be re-encoded as they are written.}
}
\details{
The file required in the argument \emph{data} may be obtained using ModestR (available at the web site \url{www.ipez.es/ModestR}), as it is shown in the following screenshot (Export/Export maps of the select branch/To RWizard Applications/To EnvNicheR). It is better do not include duplicates, i.e., records with the same longitude and latitude.
\tabular{c}{
\figure{F78}{options: width=4.4in}
}
The menu shown in the following screenshot is obtained, where it is possible to select several environmental variables. There is the option of exporting the data with the format of pseudosamples or all the valid samples. If the maps are areas, the proper way of exporting these data is to create a raster with grid cell for instance of 5 x 5, 30 x 30, 1 x 1, etc. Therefore, the output of ModestR is a list of species within each of the grid cells with the size defined by the user. If the maps are records, it is possible to use pseudosamples or to select the option valid samples.
\tabular{c}{
\figure{F79}{options: width=4.4in}
}
The format of the CSV file obtained is shown in the following screenshot, and this CSV file is the one required in this argument \emph{data}. The first only five columns must be taxonomic levels as class, order, family, subfamily, tribe, genus, subgenus, species, etc. The columns 6 and 7 must be longitude and latitude of the record, respectively. The rest of columns are the abiotic/biotic factors.
\tabular{c}{
\figure{F82}{options: width=4.7in}
}
All variables are transformed to a scale ranged between -1 and 1. For each record the X and Y polar coordinates are estimated using the following equations:
\tabular{ll}{
\eqn{X=\displaystyle\sum_{i=1}^{n}|z_j|cos(\alpha)} \tab \eqn{Y=\displaystyle\sum_{i=1}^{n}|z_j|sin(\alpha)}
}
where \emph{z} is the record of the variable \emph{j} and \emph{n} the number of variables. 

Each variable is assigned an angle (\eqn{\alpha}). The increment value of the angle is always \eqn{\frac{360}{n*2}}. If for instance the number of variables are 5, the increment angle is 36. Therefore, for the first variable if the value is \eqn{\geq0} the \eqn{\alpha} is 36 and if the value is \eqn{<0} the \eqn{\alpha} is 36+180, for the second variable if the value is \eqn{\geq0} the \eqn{\alpha} is 36+36 and if the value is \eqn{<0} the \eqn{\alpha} is 36+36+180, etc. Degrees to radians angle conversion is carried out assuming that 1 degree = 0.0174532925 radians.

Therefore, the order of the variables is important because a different \eqn{\alpha} is assigned. If the argument \emph{cor=TRUE}, the order is established calculating the correlation matrix of the variables, and ordering them in the way that each variable will be followed by the variable to which is highly correlated. The goal is to favor a larger dispersion of the data in the resulting polar coordinates system.

\strong{FUNCTIONS}

The scatter plot is performed with the function \link[IDPmisc]{iplot} of the package IDPmisc (Locher & Ruckstuhl, 2014).

\strong{EXAMPLE}

The dataset is a matrix of the presence of the wolf and the mean altitude, mean annual temperature (BIO1), mean diurnal range (BIO2), isothermality (BIO3), temperature seasonality (BIO4), maximum temperature of the warmest month (BIO5), mean annual precipitation (BIO12), primary terrestrial production (PP), slope and vegetation index (VI) in cells of 1 degree x 1 degree around the world.

The first plot shows the polar coordinates using the environmental variables selected by the user in the file obtained from ModestR (in the example altitude, BIO1, BIO12, BIO2, BIO3, BIO4, BIO5, PP, slope and VI). In this first plot, a darker color of the square indicates a higher number of records of the wolf in the cell. In this plot it is necessary to click four times with the mouse to select one or several pixels.
\tabular{c}{
\figure{F80}{options: width=2.9in}
}
The second plot shows a boxplot with the median and range of the environmental variables in the pixels selected with the mouse in the first plot.
\tabular{c}{
\figure{F81}{options: width=5in}
}
}
\value{A list of the species present in the cells selected by the user with the mouse and a summary of the environmental variables are saved in two CSV files.}
\references{
Garca-Rosell, E., Guisande, C., Gonzlez-Dacosta, J., Heine, J., Pelayo-Villamil, P., Manjarrs-Hernndez, A., Vaamonde, A. & Granado-Lorencio, C. (2013) ModestR: a software tool for managing and analyzing species distribution map databases. \emph{Ecography}, 36, 1202-1207.

Hijmans, R.J., Cameron, S.E., Parra, J.L., Jones, P.G. and Jarvis, A. (2005)Very high resolution interpolated climate surfaces for global land areas. \emph{International Journal of Climatology}, 25, 1965-1978.

IUCN (2012) The IUCN Red List of Threatened Species. Version 2012.2. \url{http://www.iucnredlist.org}. Downloaded on 17 October 2012.

Locher, R. & Ruckstuhl, A. (2014) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: https://CRAN.R-project.org/package=IDPmisc.
}
\examples{
\dontrun{
data(Z16)

F37(data=Z16 , variables=c("Altitude", "BIO1", "BIO12", "BIO2",
"BIO3","BIO4","BIO5","PP","Slope","VI"))
}
}
\keyword{F37}
