\name{F41}
\alias{F41}
\encoding{latin1}
\title{3D SCATTER PLOTS}
\description{It performs 3D scatter plots in panels, in one plot making the difference among categories and in one plot without distinguishing among categories.}
\usage{
F41(data, varZ,  varY, varX, group=NULL, panel=FALSE, CEX=1.2, PCH=NULL,
COLOR=NULL, ZLAB=NULL, YLAB=NULL, XLAB=NULL, ZLIM=NULL, YLIM=NULL,
XLIM=NULL, family="serif", cexaxis=1, cexZ=1.2, fontZ=2, rotZ=90, cexY=1.2,
fontY=2, rotY=-50, cexX=1.2, fontX=2, rotX=15, sz=20, sx=-70, sy=10, arrows=FALSE,
distance=0.8, LEGEND=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varZ}{Variable Z.}
  \item{varY}{Variable Y.}
  \item{varX}{Variable X.}
  \item{group}{Variable with the categories to be grouped.}
  \item{panel}{If it is TRUE each category of the variable \emph{group} is depicted in one panel.}
  \item{CEX}{Size of the symbols.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as different categories of the variable \emph{group}.}
  \item{COLOR}{Color of the symbols. It must be as many as different categories of the variable \emph{group}.}
  \item{ZLAB}{Legend of the Z axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLAB}{Legend of the X axis.}
  \item{ZLIM}{Vector with the limits of the Z axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{family}{It specifies the font of the plot.}
  \item{cexaxis}{Size of the axis labels.}
  \item{cexZ}{Size of the Z legend.}
  \item{fontZ}{A numeric value that defines the font of the Z legend. The value 1 is a normal type, 2 is written in bold, 3 is written in italics and 4 is written in italics and
bold.}
  \item{rotZ}{Angle of Z legend.}
  \item{cexY}{Size of the Y legend.}
  \item{fontY}{A numeric value that defines the font of the Y legend. Options as mentioned in the argument \emph{fontZ}.}
  \item{rotY}{Angle of Y legend.}
  \item{cexX}{Size of the X legend.}
  \item{fontX}{A numeric value that defines the font of the X legend. Options as mentioned in the argument \emph{fontZ}.}
  \item{rotX}{Angle of X legend.}
  \item{sz}{Perspective of axis Z.}
  \item{sy}{Perspective of axis Y.}
  \item{sx}{Perspective of axis X.}
  \item{arrows}{If it is FALSE, tick marks and labels are used instead of arrows being drawn.}
  \item{distance}{It specifies the relative distance of the axis label from the bounding box.}
  \item{LEGEND}{It allows to modify the legend of the graph with the function grid_legend.}
}
\value{3D scatter plots are obtained.}  
\details{
\strong{FUNCTIONS}

The 3D plot was performed with the function \link{lattice}[cloud] of the package lattice (Sarkar, 2008). The function grid_legend of the package vcd (Meyer et al., 2006; 2015) was used to depict the legend. For further details see Guisande & Vammonde (2012).

\strong{EXAMPLES}

The data are the percentages of three amino acids in different species of rotifers obtained from ponds of Doana National Park (Spain) (Guisande et al., 2008).

\strong{Example 1} Each species is shown in a panel with the argument \emph{panel=TRUE}.
\tabular{c}{
\figure{F90}{options: width=5.8in}
}
\strong{Example 2} All data are depicted in one plot but making the difference among species.
\tabular{c}{
\figure{F91}{options: width=3.6in}
}
\strong{Example 3} All data are depicted in one plot without making differences among species.
\tabular{c}{
\figure{F92}{options: width=3.6in}
}
}
\references{
Guisande, C., Granado-Lorencio, C, Toja, J. & Len, D. (2008 Identification of the main factors in structuring rotifer community assemblages in ponds of Doana National Park using the amino acid composition of the species. \emph{Limnetica}, 27: 273-284.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Meyer, D., Zeileis, A. & Hornik, K. (2006) The strucplot framework: Visualizing multiway contingency tables with vcd. \emph{Journal of Statistical Software}, 17: 1-48.

Meyer, D., Zeileis, A. & Hornik, K. (2015) Visualizing Categorical Data. R package version 1.4-1. Available at: \url{https://CRAN.R-project.org/package=vcd}.

Sarkar, D (2008) Lattice: Multivariate Data Visualization with R. Springer, New York. IBN 978-0-387-75968-5. \url{http://lmdvr.r-forge.r-project.org}.
}
\examples{
\dontrun{

#Example 1

data(Z17)

F41(data=Z17, varZ="Aspartate", varY="Glutamate", varX="Serine", group="Species",
panel=TRUE, cexaxis=0.8, cexZ=1, cexY=1,cexX=1)

#Example 2

data(Z17)

F41(data=Z17, varZ="Aspartate", varY="Glutamate", varX="Serine", group="Species")

#Example 3

data(Z17)

F41(data=Z17, varZ="Aspartate", varY="Glutamate", varX="Serine", COLOR="blue", PCH=15)
}
}
\keyword{F41}
