\name{F44}
\alias{F44}
\encoding{latin1}
\title{MONTE-CARLO TEST FOR ONE VARIABLE}
\description{A Monte-Carlo test is performed for testing the hypothesis, in one variable, if an observation is significantly greater or lower than a set of values belonging to a group.}
\usage{
F44(data, variable, group, group1, row, ResetPAR=TRUE,  PAR=NULL, HIST=NULL,
colorp="red", pch=18, cex=2, colorb="lightblue", breaks=10, LEGEND=NULL,
AXIS=NULL, MTEXT= NULL, TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{variable}{Variable to be selected.}
  \item{group}{Variable with the groups to be compared.}
  \item{group1}{Group to be selected within the variable \emph{group}.}
  \item{row}{Row number of the observation to be compared with the \emph{group1}.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{HIST}{It allows to specify the characteristics of the function \link[graphics]{hist}.}
  \item{colorp}{Color of the point of the observation.}
  \item{pch}{Graphic symbol of the observation (see the description of the same argument in the function \link{F1}).}
  \item{cex}{Size of the symbol of the observation.}
  \item{colorb}{Color of the bars in the histogram.}
  \item{breaks}{Number of bars of the histogram.}
  \item{LEGEND}{It allows to modify the legend of the histogram.}
  \item{AXIS}{It allows to add axes to the histogram.}
  \item{MTEXT}{It allows to add text on the margins of the histogram.}
  \item{TEXT}{It allows to add text in any area of the inner part of the histogram.}
  \item{file}{TXT FILE. Name of the output file with the results of the Monte-Carlo test.}
}
\value{It is depicted a histogram with the frequencies of the \emph{group1} and the point of the observation. It is saved a TXT file with the results of the Monte-Carlo test.}  
\details{

In the Monte-Carlo test, if the alternative hypothesis is \emph{greater}, a p-value is estimated as: (number of random values equal to or greater than the observed one + 1)/(number of permutations + 1). The null hypothesis is rejected if the p-value is less than the significance level.

If the alternative hypothesis is \emph{smaller}, a pvalue is estimated as: (number of random values equal to or less than the observed one + 1)/(number of permutations + 1). Again, the null hypothesis is rejected if the p-value is less than the significance level. 

\strong{FUNCTIONS}

The histogram is performed with the function \link[graphics]{hist} of base graphics package.

The Monte-Carlo test was performed with the function \link[ade4]{as.randtest} of the package ade4 (Chessel et al., 2004; Dray et al., 2007; 2015).

\strong{EXAMPLES}

For the example, morphometric data of three families of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010).

In the example the morphometric variable M12 is compared between the observation of the row number 54, a individual of the species \emph{Triportheus magdalenae}, and all values of the species \emph{Triportheus angulatus}.

In the histogram, the bars are the frequency of the variable M12 for the species \emph{Triportheus angulatus} and the red point is the observation of the species \emph{Triportheus magdalenae}.
\tabular{c}{
\figure{F97}{options: width=2.2in}
}
When the alternative hypothesis is being smaller, the p-value is 0.055 and, therefore, it may be concluded that the observation of the species \emph{Triportheus magdalenae} is significantly smaller than the individuals of the species \emph{Triportheus angulatus} for the variable M12. However, when the alternative hypothesis is being greater, the p-value is 1 and, therefore, it may be concluded that the observation of the species \emph{Triportheus magdalenae} is not significantly greater than the individuals of the species \emph{Triportheus angulatus} for the variable M12.
\tabular{c}{
\figure{R9}{options: width=3.7in}
}
}
\references{
Chessel, D. and Dufour, A.B. and Thioulouse, J. (2004) The ade4 package-I- One-table methods. \emph{R News}, 4, 5-10.

Dray, S. & Dufour, A.B. (2007) The ade4 package: implementing the duality diagram for ecologists. \emph{Journal of Statistical Software}, 22(4), 1-20.

Dray, S. & Dufour, A.B. and Chessel, D. (2007) The ade4 package-II: Two-table and K-table methods. \emph{R News}, 7(2), 47-52.

Dray , S., Dufour , A-B. & Thioulouse , J. (2015) Analysis of Ecological Data : Exploratory and Euclidean Methods
in Environmental Sciences. R package version 1.7-2. Available at: \url{https://CRAN.R-project.org/package=ade4}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(Z1)

F44(data=Z1, variable="M12", group="Species", group1="Triportheus angulatus", row=54)
}
}
\keyword{F44}
