\name{F49}
\alias{F49}
\encoding{latin1}
\title{BARPLOTS 	WITH CYLINDRICAL BARS FOR ONE VARIABLE}
\description{It performs a barplot for one variable, with or without error bars.}
\usage{
F49(data, varY, varX, method="mean", dev=NULL, BARPLOT=NULL, ResetPAR=TRUE,
PAR=NULL, order=NULL, OrderCat=NULL, LabelCat=NULL, XLAB=NULL, YLAB=NULL,
XLIM=NULL, YLIM=NULL, COLOR="green", LEGEND=NULL , AXIS=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Qualitative independent variable with the categories.}
  \item{method}{The average of each category of the independent variable \emph{varX} is estimated with the "mean" or the "median".}
  \item{dev}{If it is not NULL, the error bars may be estimated using the standard deviation ("sd") or the standard error ("se").}
  \item{BARPLOT}{It accesses the function \link[plotrix]{barp} that allows to modify the barplot.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{order}{If it is NULL the categories are ordered as found in the variable \emph{FactorX}, if it is "increasing" are ordered from lesser to greater median or mean according to the method selected in the argument \emph{method}, if it is "decreasing" are ordered from greater to lesser median or mean, if it is "alhaAZ" are ordered from A to Z and if it is "alphaZA" from Z to A.} 
  \item{OrderCat}{It allows to specify a vector with the order in which the categories are shown. If this argument is specified, the argument \emph{order} is not taken into account.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{COLOR}{Color of bars. It must be a single color or as many as different categories of the variable \emph{varX}.}
  \item{LEGEND}{It allows to add a legend to the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A barplot for one variable, with or without error bars, is obtained.}
\details{
\strong{FUNCTIONS}

The plot is performed with the functions \link[plotrix]{barp} of the package plotrix (Lemon et al., 2015) and \link[graphics]{arrows} of base graphics package. For further details see Guisande & Vammonde (2012).

\strong{EXAMPLES}

For the example, morphometric data of three families of freshwater fishes are used. For details see Guisande et al. (2010).

\strong{Example 1} The mean value without standard deviations for the M12 is shown for all genera.
\tabular{c}{
\figure{F107}{options: width=4.2in}
}
\strong{Example 2} The mean value for the M12 is shown for all genera and the standard deviations with the argument \emph{dev="sd"}.
\tabular{c}{
\figure{F106}{options: width=4.2in}
}
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Lemon, J., Bolker, B., Oom, S., Klein, E., Rowlingson, B., Wickham, H., Tyagi, A., Eterradossi, O., Grothendieck, G., Toews, M., Kane, J., Turner, R., Witthoft, C., Stander, J., Petzoldt, T., Duursma, R., Biancotto, E., Levy, O., Dutang, C., Solymos, P., Engelmann, R., Hecker, M., Steinbeck, F., Borchers, H., Singmann, H., Toal, T. & Ogle, D. (2015) Various plotting functions. R package version 3.5-11. Available at: \url{https://CRAN.R-project.org/package=plotrix}.
}
\examples{
\dontrun{

#Example 1

data(Z1)

F49(data=Z1, varY="M12", varX="Genus",  order="increasing")

#Example 2

F49(data=Z1, varY="M12", varX="Genus",  dev="sd")
}
}
\keyword{F49}
