\name{F54}
\alias{F54}
\encoding{latin1}
\title{TERNARY DIAGRAMS}
\description{It performs a ternary diagram for one or several groups.}
\usage{
F54(data, varX, varY, varZ, group=NULL, mean=FALSE, cexpoint=1, cexmean=1, 
cexaxis=1, cexlab=1.2, segments=TRUE, nseg=5, colseg="grey80", axisd=1, meand=2,
XLAB=NULL, YLAB=NULL, ZLAB=NULL, XLIM=NULL, YLIM=NULL, ZLIM=NULL,
COLOR=NULL, PCH=NULL, FAMILY="Arial", MAR=c(1,1,3,1), LEGEND=NULL,
MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varX}{Variable X.}
  \item{varY}{Variable Y.}
  \item{varZ}{Variable Z.}
  \item{group}{Variable with the categories to be grouped.}
  \item{mean}{If it is TRUE the mean of all values or the mean of each group (if the argument \emph{group} is not NULL) is plotted.}
  \item{cexpoint}{Size of the symbols.}
  \item{cexmean}{Size of the labels of the means.}
  \item{cexaxis}{Size of the labels of the axes.}
  \item{cexlab}{Size of the legends of the axes.}
  \item{segments}{If it is TRUE, segments into the triangle are drawn.}
  \item{nseg}{Number of inside segments.}
  \item{colseg}{Color of inside segments.}
  \item{axisd}{Number of digits of the labels of the axes.}
  \item{meand}{Number of digits of the labels of the means.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{ZLAB}{Legend of the Z axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{ZLIM}{Vector with the limits of the Z axis.}
  \item{COLOR}{Color of the symbols. If the argument \emph{group} is not NULL, it must be as many as different categories of the variable \emph{group}.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It the argument \emph{group} is not NULL, it must be as many as different categories of the variable \emph{group}.}
  \item{FAMILY}{It specifies the font of the text.}
  \item{MAR}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the figure.}
  \item{LEGEND}{It allows to modify the legend.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A ternary diagram is obtained.}  
\details{
The barycenter of the triangle formed by the three variables was used as the centroid of the three variables. For further details see Guisande & Vammonde (2012).
\tabular{c}{
\figure{F122}{options: width=2.3in}
}
\strong{EXAMPLES}

For the examples, morphometric data of three families of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010).

\strong{Example 1} The ternary diagram is performed with the variables M12, M23 and M24.
\tabular{c}{
\figure{F118}{options: width=3.8in}
}
\strong{Example 2} The mean value is depicted with the argument \emph{mean=TRUE} and the limits are modified.
\tabular{c}{
\figure{F119}{options: width=3.8in}
}
\strong{Example 3} The different families are identified with the argument \emph{group="Family"}.
\tabular{c}{
\figure{F120}{options: width=3.8in}
}
\strong{Example 4} The mean value for each family is depicted with the argument \emph{mean=TRUE}.
\tabular{c}{
\figure{F121}{options: width=3.8in}
}
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.
}
\examples{
\dontrun{

#Example 1

data(Z8)

F54(data=Z8, varX="M12", varY="M21", varZ="M24")

#Example 2

data(Z8)

F54(data=Z8, varX="M12", varY="M21", varZ="M24", mean=TRUE, XLIM=c(0,1),
YLIM=c(0,1), ZLIM=c(0,1))

#Example 3

data(Z8)

F54(data=Z8, varX="M12", varY="M21", varZ="M24", group="Family")

#Example 4

data(Z8)

F54(data=Z8, varX="M12", varY="M21", varZ="M24", group="Family", mean=TRUE)
}
}
\keyword{F54}
