\name{F57}
\alias{F57}
\encoding{latin1}
\title{ASSOCIATION PLOT}
\description{It performs an association plot.}
\usage{
F57(data, varX, varY, varZ=NULL, OrderCatX=NULL, LabelCatX=NULL, OrderCatY=NULL,
LabelCatY=NULL, OrderCatZ=NULL, LabelCatZ=NULL, APLOT=NULL, shade=TRUE,
compress=TRUE, main="", family= "Arial", cex.axis=12, cex.lab=15, cex.main=17,
cex.legend=12, font.axis=1, font.lab=2, font.main=2, legend.text= "Pearson\nresiduals",
XLAB=NULL, YLAB=NULL, ZLAB=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varX}{Qualitative variable X.}
  \item{varY}{Qualitative variable Y.}
  \item{varZ}{Qualitative variable Z.}
  \item{OrderCatX}{It allows to specify a vector with the order in which the categories of the variable \emph{varX} are shown.}
  \item{LabelCatX}{It allows to specify a vector with the names of the categories of the variable \emph{varX}.}
  \item{OrderCatY}{It allows to specify a vector with the order in which the categories of the variable \emph{varY} are shown.}
  \item{LabelCatY}{It allows to specify a vector with the names of the categories of the variable \emph{varY}.}
  \item{OrderCatZ}{It allows to specify a vector with the order in which the categories of the variable \emph{varZ} are shown.}
  \item{LabelCatZ}{It allows to specify a vector with the names of the categories of the variable \emph{varZ}.}
  \item{APLOT}{It accesses the function \link[vcd]{assoc} that allows to modify the association plot.}
  \item{shade}{If it is TRUE the results of the statistical Chi square of Pearson are shown and, in addition, the categories that are significantly different are shaded.}
  \item{compress}{If it is FALSE the space between rows and columns is chosen so that the total of heights and widths of the rows and columns are equal. If TRUE, the space between rows and columns is fixed and, therefore, the graph is more compressed.}
  \item{main}{Title of the plot.}
  \item{family}{It specifies the font of the text.}
  \item{cex.axis}{Size of the labels of the axes.}
  \item{cex.lab}{Size of the text of the legends.}
  \item{cex.main}{Size of the graph title text.}
  \item{cex.legend}{Size of text in the bar legend.}
  \item{font.axis}{A numeric value that defines the font of the axis labels. The value 1 is a normal type, 2 is written in bold, 3 is written in italics and 4 is written in italics and bold.}
  \item{font.lab}{A numeric value that defines the font of the legends.}
  \item{font.main}{A numeric value that defines the font of the title of the graph.}
  \item{legend.text}{Text of the bar legend.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{ZLAB}{Legend of the Z axis.}
}
\value{A association plot is obtained.}  
\details{
\strong{FUNCTIONS}

The graph is performed with the function \link[vcd]{assoc} of the package vcd (Meyer et al., 2006; 2008; 2015). For further details see Guisande & Vammonde (2012).

\strong{EXAMPLES}

Smoking behaviour of men and women who smoke in different work centres.

\strong{Example 1} In the first example, the question is whether there are differences between the group of people with any of the smoking parents and the group that their parents do not smoke, in the proportion of different types of degrees of smoker.

The figure shows the graphical representation of the contingency table. The categories of the variable X are ordered with the argument \emph{OrcerCatX}.

This chart also shows the results of the test \eqn{\chi^2} with a p < 0.001. As there are categories with color, the null hypothesis that the samples are homogeneous is rejected, that is to say, there are significant differences between the group with one of their smoking parents and the group without smoking parents, in the percentage of the different types of smokers.

The chart also gives a very important additional information, the categories where the differences are significant and which are contributing to that, as a whole, the test \eqn{\chi^2} is significant. 

The gray color categories are not significantly different, while the categories with color are significantly different. In particular, it notes that under the category of non-smoking parents, for both men and women, there is a significantly higher proportion of people who do not smoke (the bars are above the dotted line). On the contrary, the number of people who do not smoke is significantly lower in the group of smoking parents (the bar is below the dotted line).

Therefore, the fact that the parents do not smoke appears to foster their children not to smoke. However, once a person smokes, the degree to which smoke does not vary depending on whether the parents smoke or not smoke, as it could be observed that in all the categories of smokers, the color of the bars is gray.
\tabular{c}{
\figure{F127}{options: width=5in}
}
\strong{Example 2} As in the example 1 but adding the variable Sex. The conclusions are the same than in the example 1. 
\tabular{c}{
\figure{F128}{options: width=5in}
}
}
\references{
Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Meyer, D., Zeileis, A. & Hornik, K. (2006) The strucplot framework: Visualizing multiway contingency tables with vcd. \emph{Journal of Statistical Software}, 17: 1-48.

Meyer, D., Zeileis, A. &Hornik, K. (2008) Visualizing contingency tables. In Chun-Houh Chen, Wolfang Hrdle, and Antony Unwin, editors, Handbook of Data Visualization, Springer Handbooks of Computational Statistics, pages 589-616. Springer-Verlag, New York. ISBN 978-3-540-33036-3.

Meyer, D., Zeileis, A. & Hornik, K. (2015) Visualizing Categorical Data. R package version 1.4-1. Available at: \url{https://CRAN.R-project.org/package=vcd}.
}
\examples{
\dontrun{

#Example 1

data(Z20)

F57(data=Z20, varX="Smoker", varY="Parents", OrderCatX=c("1 to 10 cigarettes a day",
"11 to 20 cigarettes a day", "1 to 2 cigarette packets", "More than 2 cigarette packets",
"Non-smoker"))

#Example 2

data(Z20)

F57(data=Z20, varX="Smoker", varY="Parents", varZ="Sex", OrderCatX=c("1 to 10 cigarettes a day",
"11 to 20 cigarettes a day", "1 to 2 cigarette packets", "More than 2 cigarette packets",
"Non-smoker"))
}
}
\keyword{F57}
