\name{F66}
\alias{F66}
\encoding{latin1}
\title{CALENDAR PLOT}
\description{It performs a calendar plot for time series data.}
\usage{
F66(data, date, var, winds=NULL, windd=NULL, year, month,
date.format="\%d/\%m/\%Y \%H:\%M", annotate="date", key.position="right",
COLOR="heat", MAIN=NULL, CEX.LIM=c(0.6,1), BREAKS=FALSE, LABELS=NULL,
STATISTIC="mean", CALENDAR=NULL, dec=",")}
\arguments{
  \item{data}{Data file.}
  \item{date}{Variable with the date.}
  \item{var}{Variable to be depicted.}
  \item{winds}{Variable with the wind speed.}
  \item{windd}{Variable with the wind direction.}
  \item{year}{It is possible to select one or several years in a vector.}
  \item{month}{It is possible to select one or several months in a vector.}
  \item{date.format}{The format of date: "\%d/\%m/\%Y \%H:\%M", "\%d/\%m/\%Y", "\%Y/\%m/\%d \%H:\%M", "\%Y/\%m/\%d", "\%d-\%m-\%Y \%H:\%M", "\%d-\%m-\%Y", "\%Y-\%m-\%d \%H:\%M" or "\%Y-\%m-\%d"}
  \item{annotate}{This option controls what appears on each day of the calendar. The option "date" shows day of the month; "wd" shows vector-averaged wind direction, "ws" shows vector-averaged wind direction scaled by wind speed and "value" which shows the daily mean value.}
  \item{key.position}{Location where the scale key is to plotted: "top", "right", "bottom" and "left".}
  \item{COLOR}{Colours to be used for plotting. Options include "default", "increment", "heat", "jet" and user defined.}
  \item{MAIN}{The main title of the plot.}
  \item{CEX.LIM}{For the annotation of concentration labels on each day. The first sets the size of the text below lim and the second sets the size of the text above lim.}
  \item{BREAKS}{If a categorical scale is required then these breaks will be used. If it is TRUE is calculated automatically but it may be defined by the user with a vector.}
  \item{LABELS}{If a categorical scale is required then these labels will be used. There is one less label than breaks. If it is TRUE is calculated automatically as "Very low", "Low", "Medium", "High" and "Very High", but it may be defined by user.}
  \item{STATISTIC}{The statistic to apply when aggregating the data. Can be one of "mean", "max", "min", "median", "frequency", "sd" or "percentile".}
  \item{CALENDAR}{It accesses the function \link[openair]{calendarPlot} that allows to modify many different aspects of the plot.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
}
\value{A calendar plot is depicted.}  
\details{
\strong{FUNCTIONS}

The calendar plot is performed with the function \link[openair]{calendarPlot} of the package openair (Carslaw & Ropkins, 2012; 2016).

\strong{EXAMPLES}

For the examples, hourly data of air pollutants, wind speed and wind direction in Santiago de Compostela (Spain) from 1/11/2015 to 31/12/2015 are used. The data were obtained from \url{http://www.meteogalicia.es/web/index.action}.

\strong{Example 1}. Daily mean values of nitrogen dioxide for the all period.
\tabular{c}{
\figure{F149}{options: width=3.8in}
}
\strong{Example 2}. Daily means of particulate matter 10 micrometers or less in diameter in November. The mean values are shown each day due to the argument \emph{annotate="value"}.
\tabular{c}{
\figure{F150}{options: width=3in}
}
\strong{Example 3}. Daily means of ozone in categorical scale with the argument \emph{BREAKS=TRUE}.
\tabular{c}{
\figure{F151}{options: width=3in}
}
\strong{Example 4}. Daily means of nitrogen oxides showing vector-averaged wind direction with the argument \emph{annotate="wd"}.
\tabular{c}{
\figure{F152}{options: width=3in}
}
}
\references{
Carslaw, D. & Ropkins, K. (2012) openair - An R package for air quality data analysis. \emph{Environmental Modelling & Software}, 27-28: 52-61. doi \url{10.1016/j.envsoft.2011.09.008}.
Carslaw, D. & Ropkins, K. (2016) Tools for the Analysis of Air Pollution Data. R package version 1.6.7. Available at: \url{https://CRAN.R-project.org/package=openair}.
}
\examples{
\dontrun{

#Example 1

data(Z22)

F66(data=Z22,  date="date", var="NO2")

#Example 2

F66(data=Z22, date="date", var="PM10",  month=11, annotate="value", CEX.LIM=c(1,1))

#Example 3

F66(data=Z22, date="date", var="O3", BREAKS=TRUE, annotate="value")

#Example 4

F66(data=Z22, date="date", var="NOX", wind="Wd", winds="Ws", annotate="wd")
}
}
\keyword{F66}
