\name{F70}
\alias{F70}
\encoding{latin1}
\title{TIME PLOTS}
\description{It performs interactive time series plots with the function \link[plotly]{plot_ly} of the package plotly (Sievert et al., 2016). For further details see \url{https://plot.ly/r/reference/} and \url{https://github.com/ropensci/plotly}.}
\usage{
F70(data, date, var, symbolvar=NULL, colorvar=NULL, year, month, avg.time="day",
date.format="\%d/\%m/\%Y \%H:\%M", ticks=10, symbols=NULL, colors=NULL, mode="lines",
TRACE=FALSE, LEGEND=FALSE, MAIN=NULL, XLAB=NULL, YLAB=NULL,
XFONT=list(family = "Courier New, monospace", size=24,  color = "black"),
YFONT=list(family="Courier New, monospace", size=24, color="black"),
marker=list(size=10), yaxis=list(title=ylab, titlefont=YFONT),
xaxis=list(title=xlab, autotick=TRUE, dtick=dtick, titlefont=XFONT),
line=list(color=colors, dash="solid"), traceline=list(color=colors,
dash="dash"), dec=",")
}
\arguments{
  \item{data}{Data file.}
  \item{date}{Variable with the date.}
  \item{var}{Variable to be depicted in the Y axis.}
  \item{symbolvar}{Optionally a variable name or a (discrete) vector to use for symbol encoding.}
  \item{colorvar}{Optionally a variable name or a vector to use for color mapping.}
  \item{year}{It is possible to select one or several years in a vector.}
  \item{month}{It is possible to select one or several months in a vector.}
  \item{avg.time}{This defines the time period to average to: "hour", "day", "DSTday", "week", "month", "2 month", "quarter", "year" and so on. For further details see function \link[openair]{timePlot} of the package openair (Carslaw, 2016).}
  \item{date.format}{The format of date: "\%d/\%m/\%Y \%H:\%M", "\%d/\%m/\%Y", "\%Y/\%m/\%d \%H:\%M", "\%Y/\%m/\%d", "\%d-\%m-\%Y \%H:\%M", "\%d-\%m-\%Y", "\%Y-\%m-\%d \%H:\%M" or "\%Y-\%m-\%d"}
  \item{ticks}{Number of ticks in the axes.}
  \item{symbols}{A character vector of symbol types. Possible values: "dot", "cross", "diamond", "square", "triangle-down", "triangle-left", "triangle-right" or "triangle-up".}
  \item{colors}{Either a colorbrewer2.org palette name (e.g. "YlOrRd" or "Blues"), or a vector of colors to interpolate in hexadecimal "#RRGGBB" format, or a color interpolation function like colorRamp.}
  \item{mode}{It determines the drawing mode of the plot: "lines", "markers", "lines+markers", "lines+markers+text", "markers+text", "lines+text" or "none"}
  \item{TRACE}{If it is TRUE a trace is added.}
  \item{LEGEND}{It it is TRUE the legend is shown.}
  \item{MAIN}{Main title of the plot.}
  \item{XLAB}{Legend of X axis.}
  \item{YLAB}{Legend of Y axis.}
  \item{XFONT}{Font of X axis.}
  \item{YFONT}{Font of Y axis.}
  \item{marker}{It defines the format of the symbols.}
  \item{yaxis}{It defines the format of Y axis.}
  \item{xaxis}{It defines the format of X axis.}
  \item{line}{It defines the format of the line connecting the points.}
  \item{traceline}{It defines the format of the trace line.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
}
\value{Interactive time series plots are depicted.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[plotly]{plot_ly} of the package plotly (Sievert et al., 2016).

\strong{EXAMPLES}

For the example 1, hourly data of air pollutants, wind speed and wind direction in Santiago de Compostela (Spain) from 1/11/2015 to 31/12/2015 are used. The data were obtained from \url{http://www.meteogalicia.es/web/index.action}. For the examples 2 and 3, the data are maximum and minimum temperatures and precipitation in 1990 and 2000 in three cities in Spain: Huelva, Palma de Mallorca and Vigo (\url{http://www.aemet.es/es/portada}).

\strong{Example 1}. Without groups. Daily means of wind speed.
\tabular{c}{
\figure{F159}{options: width=5.2in}
}
\strong{Example 2}. With groups. Monthly means of minimum temperature in three cities of Spain. The symbols of the cities are specified with the argument \emph{symbolvar="City"} and the symbols may be optionally modified with the argument \emph{symbols}.
\tabular{c}{
\figure{F160}{options: width=5.2in}
}
\strong{Example 3}. With groups. Weekly means of maximum temperature in three cities of Spain. The colors are specified with the argument \emph{colorvar="City"} and the colors may be optionally modified with the argument \emph{colors}.
\tabular{c}{
\figure{F161}{options: width=5.2in}
}
}
\references{
Sievert, C., Parmer, C., Hocking, T., Chamberlain, S., Ram, K., Corvellec, M. & Despouy, P. (2016) Create Interactive Web Graphics via Plotly's JavaScript Graphing Library. R package version 2.0.16. Available at: \url{https://CRAN.R-project.org/package=plotly}.
}
\examples{
\dontrun{

#Example 1. Without groups

data(Z22)

F70(data=Z22, date="date", var="Ws", TRACE=TRUE, YLAB="Wind speed (m/s)")

#Example 2. With groups

data(Z23)

F70(data=Z23, date="date", var="T.min", symbolvar="City", avg.time="month",
symbols=c("dot","square","circle-open"), date.format="%d/%m/%Y",
year=2000, mode="lines+markers", YLAB="Minimum temperature")

#Example 3. With groups

data(Z23)

F70(data=Z23, date="date", var="T.max", colorvar="City", avg.time="week",
date.format="%d/%m/%Y", year=2000, mode="lines+markers", colors=rainbow(3),
YLAB="Maximun temperature")
}
}
\keyword{F70}
