\name{F84}
\alias{F84}
\encoding{latin1}
\title{ADDITIONAL AXES IN LINE CHARTS AND SCATTER PLOTS FOR VARIABLE X QUANTITATIVE}
\description{It is possible to add up to 3 additional axes to line charts and scatterplots with or without text labels, and a regression model.}
\usage{
F84(data, varX, varY, varY1=NULL, varY2=NULL, varY3=NULL, textlabelY=NULL,
textlabelY1=NULL, textlabelY2=NULL, textlabelY3=NULL, type=NULL, label=NULL,
MAR1=c(5,5,3,4), MAR2=c(5,5,3,8), MAR3=c(5,5,3,12), reg=FALSE, model=NULL,
outliers=FALSE, quant1=0.05, quant2=0.95, ResetPAR=TRUE, PAR=NULL, XLAB=NULL,
YLAB=NULL, YLAB1=NULL, YLAB2=NULL, YLAB3=NULL, XLIM=NULL, YLIM=NULL, YLIM1=NULL,
YLIM2=NULL, YLIM3=NULL, CEX=1.2, FONTLAB=2, CEXLAB=1.5, COLOR=NULL,
COLORR=NULL, PCH=NULL, lty=NULL, ltyL=NULL, lwd=2.5, lwdL=1, LEGEND=NULL,
MTEXT= NULL, TEXT=NULL, file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varX}{Quantitative independent variable.}
  \item{varY}{Dependent variable.}
  \item{varY1}{First additional variable.}
  \item{varY2}{Second additional variable.}
  \item{varY3}{Third additional variable.}
  \item{textlabelY}{Variable with the text labels for varY.}
  \item{textlabelY1}{Variable with the text labels for varY1.}
  \item{textlabelY2}{Variable with the text labels for varY2.}
  \item{textlabelY3}{Variable with the text labels for varY3.}
  \item{type}{Character string giving the type of plot desired. It must be as many as the number of variables Y. The following values are possible: "p" for points, "l" for lines, "b" for both points and lines (default), "c" for empty points joined by lines, "o" for overplotted points and lines, "s" and "S" for stair steps and "h" for histogram-like vertical lines. Finally, "n" does not produce any points or lines.}
  \item{label}{It allows to specify the characteristics of the text labels with the function \link[graphics]{text}.}
  \item{MAR1}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot when adding varY1.}
  \item{MAR2}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot when adding varY1 and varY2.}
  \item{MAR3}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot when adding varY1, varY2 and varY3.}
  \item{reg}{If TRUE a regression model is performed.}
  \item{model}{Regression model: "Linear" (default), "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic", "Inverse".  It is not considered the model in those cases in which there is the logarithm that apply to any of the variables, if any value of the variable, which applies the logarithm, is zero or negative. The inverse model is not calculated if any value of the independent variable is zero. It must be as many as the number of variables Y.}
  \item{outliers}{If it is TRUE, the outliers are removed using the selected regression model.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y ax1s.}
  \item{YLAB1}{Legend of the Y1 ax1s.}
  \item{YLAB2}{Legend of the Y2 ax1s.}
  \item{YLAB3}{Legend of the Y3 ax1s.}
  \item{XLIM}{Limits of X axis.}
  \item{YLIM}{Limits of Y axis.}
  \item{YLIM1}{Limits of Y1 axis.}
  \item{YLIM2}{Limits of Y2 axis.}
  \item{YLIM3}{Limits of Y3 axis.}
  \item{CEX}{Size of the symbols.}
  \item{FONTLAB}{Family font of the legends.}
  \item{CEXLAB}{Size of the legends.}
  \item{COLOR}{Color of the symbols. It must be as many as the number of variables Y.}
  \item{COLORR}{Color of the line of the regression model. It must be as many as the number of variables Y.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as the number of variables Y.}
  \item{lty}{Type of the regression line (see the description of the same argument in the function \link{F1}). It must be as many as the number of variables Y.}
  \item{ltyL}{Type of the line chart (see figure of the argument \emph{lty} in the function \link{F1}). It must be as many as the number of variables Y.}
  \item{lwd}{Line width of the regression line relative to the default (default=1), so 2 is twice as wide.}
  \item{lwdL}{Line width of the chart relative to the default (default=1), so 2 is twice as wide.}
  \item{LEGEND}{It allows to modify the legend of the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
  \item{file}{TXT FILE. If the argument \emph{reg=TRUE} a TXT file is saved with the information of the regressions.}
}
\value{Line charts and scatterplot with or without linear regression with additional axes are obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[graphics]{plot.default} of base graphics package and the linear regression with the function \link[stats]{lm} of base stats package, the function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) to perform the test of Normality Kolmogorov-Smirnov with Lilliefors'correction, the function \link[lmtest]{dwtest} of the package lmtest (Hothorn et al., 2013) to analyze the autocorrelation with the test and the Durbin-Watson statistic function \link[lmtest]{bptest} of the package lmtest (Hothorn et al., 2013) to perform the Breusch-Pagan test of homoscedasticity.

\strong{EXAMPLES}

\strong{Example 1} Monthly temperature in Huelva (Spain) in the year 2000.
\tabular{c}{
\figure{F190}{options: width=5.5in}
}
\strong{Example 2} Monthly temperature in Palma de Mallorca (Spain) in the year 2000. Text labels are assigned to the points with the argument \emph{textlabel="Season"}. Moreover, a different color is assigned to each text label using a variable with colors.
\tabular{c}{
\figure{F191}{options: width=5.3in}
}
\strong{Example 3} A cubic regression line is added with the arguments \emph{reg=TRUE} and \emph{model}. It is shown the relationships between year and the percentages of unemployment older than 65 and younger than 15, and the growth rate in North America from 1968 to 2010.
\tabular{c}{
\figure{F192}{options: width=5.3in}
}
}
\references{
Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, \strong{38}, 159-171.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{https://CRAN.R-project.org/package=nortest}.

Hothorn, T. et al., (2013) Testing Linear Regression Models. R package version 0.9-33. Available at: \url{https://CRAN.R-project.org/package=lmtest}.
}
\examples{
\dontrun{

#Example 1

data(Z13)

data<-subset(Z13,(City == "Huelva") &  (Year == 2000))

F84(data=data, varX="Month", varY="Temperature",  varY1="Precipitation",
TEXT = c("x = 10.5", "y=12", "labels='Huelva\nyear 2000'", "font=2", "cex=1.3"))

#Example 2

data(Z13)

data<-subset(Z13,(City=="Palma de Mallorca") & (Year==2000))

colorlabel<-as.character(data[,"Color"])

F84(data=data, varX="Month", varY="Temperature", varY1="Precipitation",
textlabelY="Season", label = c("pos=3" , "col=colorlabel"), YLIM=c(10,28),
YLIM1=c(0,1.7), TEXT = c("x=10.5", "y=12", "labels='Palma de Mallorca\nyear 2000'",
"font=2", "cex=1.3"))

#Example 3

data(Z3)

data<-subset(Z3,(Region== "North America"))

F84(data=data, varX="Year", varY="Unemployment.younger.15",
varY1="Unemployment.older.65", varY2="Growth", type=c("p","p","p"),
YLAB="Percentage of unemployment younger than 15",
YLAB1="Percentage of unemployment older than 65", reg="TRUE",
model=c("Cubic","Cubic","Cubic"))
}
}
\keyword{F84}
